@@ -19,6 +19,8 @@
 !   or see https://www.gnu.org/licenses/licenses.html#GPL .              !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
+#include "../config.h"
+
 module grafic_io
 
   use grafic_types
@@ -100,16 +102,16 @@ contains
 
     ! Local variables
     !real(sp), allocatable, dimension(:) :: tampon
-    integer :: record_size
+    !integer :: record_size
     !integer(RECORD_FLAG) :: taille_tampon ! kind values are implementation dependent!
 
     real(c_float), allocatable, dimension(:), target :: tampon
     integer(c_int32_t), target :: taille_tampon
 
     integer :: n2x
-    integer(i8b) :: index, index2, offset, length, toto
-    integer :: idummy=0
-    integer :: i,j,k,myid,ierr
+    integer(i8b) :: index, index2, offset, length !, toto
+    !integer :: idummy=0
+    integer :: i,j,k !,myid,ierr
     logical :: padding, white
 
     padding=.false.
@@ -201,16 +203,16 @@ contains
 
     ! Local variables
     !real(sp), allocatable, dimension(:) :: tampon
-    integer :: record_size
+    !integer :: record_size
     !integer(RECORD_FLAG) :: taille_tampon
 
     real(c_float), allocatable, dimension(:), target :: tampon
     integer(c_int32_t), target :: taille_tampon
 
     integer :: n2x
-    integer(i8b) :: index, index2, offset, length, toto
-    integer :: idummy=0
-    integer :: i,j,k,myid,ierr
+    integer(i8b) :: index, index2, offset, length !, toto
+    !integer :: idummy=0
+    integer :: i,j,k !,myid,ierr
     logical :: padding, white
 
 
@@ -301,7 +303,7 @@ contains
     logical, optional :: white_in ! Different header for white noise file
     ! Local variables
     !real(sp), allocatable, dimension(:) :: tampon
-    integer :: record_size
+    !integer :: record_size
     !integer(RECORD_FLAG) :: taille_tampon ! kind values are implementation dependent!
 
     real(c_float), allocatable, dimension(:), target :: tampon
@@ -309,9 +311,9 @@ contains
 
     integer :: n2x
     integer(i8b) :: index, index2, offset, length
-    integer :: idummy=0
+    !integer :: idummy=0
     integer :: i,j,k
-    integer :: myid,ierr
+    !integer :: myid,ierr
     logical :: padding
     logical :: white
 
@@ -413,7 +415,7 @@ contains
     logical, optional :: white_in ! Different header for white noise file
     ! Local variables
     !real(sp), allocatable, dimension(:) :: tampon
-    integer :: record_size
+    !integer :: record_size
     !integer(RECORD_FLAG) :: taille_tampon
 
     real(c_float), allocatable, dimension(:), target :: tampon
@@ -421,9 +423,9 @@ contains
 
     integer :: n2x
     integer(i8b) :: index, index2, offset, length
-    integer :: idummy=0
+    !integer :: idummy=0
     integer :: i,j,k
-    integer :: myid,ierr
+    !integer :: myid,ierr
     logical :: padding
     logical :: white
 
@@ -538,7 +540,14 @@ contains
 
   subroutine grafic_read_header_white(filename,nx,ny,nz,iseed)
 
-    integer, intent(out) :: nx,ny,nz,iseed
+    use iso_C_binding
+    integer, intent(out) :: nx,ny,nz
+#ifdef HAVE_LIBGSL
+    integer(c_long), intent(out) :: iseed
+#else
+    integer, intent(out) :: iseed
+#endif
+
     character(len=128), intent(in) :: filename
     logical :: ok
 
@@ -570,7 +579,13 @@ contains
 
   subroutine grafic_write_header_white(filename,nx,ny,nz,iseed)
 
-    integer, intent(in) :: nx,ny,nz,iseed
+    use iso_C_binding
+    integer, intent(in) :: nx,ny,nz
+#ifdef HAVE_LIBGSL
+    integer(c_long), intent(in) :: iseed
+#else
+    integer, intent(in) :: iseed
+#endif
     character(len=128), intent(in) :: filename
 
     open(2,file=filename,form='unformatted',status='unknown')
