@@ -29,7 +29,7 @@ module grafic_types
   integer, parameter :: sp_bytes = 4
 
   integer, parameter :: i4b=selected_int_kind(9)
-  integer, parameter :: i8b=selected_int_kind(16)
+  integer, parameter :: i8b=selected_int_kind(18) !log(2*10^18)/log(2)=60.8
   integer, parameter :: dpc=kind((1.0_dp,1.0_dp))
 
   REAL(kind=dp), PARAMETER, public :: PI=3.141592653589793238462643383279502884197_dp
