@@ -35,13 +35,20 @@ program grafic1
   use grafic_io
   use normalize
 
+  use iso_C_binding
+  use wrap_rfftw3d_mod
+
+
   implicit none
 #include "grafic1.inc"
 #ifdef ADD1US
 #define  rfftw3d_f77_create_plan  rfftw3d_f77_create_plan_
 #define  rfftwnd_f77_destroy_plan rfftwnd_f77_destroy_plan_
 #define  rfftwnd_f77_one_real_to_complex rfftwnd_f77_one_real_to_complex_
-#define  rfftw3d_f77_mpi_create_plan  rfftw3d_f77_mpi_create_plan_
+  /*
+  mpgrafic-0.3.10 - shifted this routine to interface with iso_C_binding;
+  #define  rfftw3d_f77_mpi_create_plan  rfftw3d_f77_mpi_create_plan_
+  */
 #define  rfftwnd_f77_mpi_destroy_plan rfftwnd_f77_mpi_destroy_plan_
 #define  rfftwnd_f77_mpi rfftwnd_f77_mpi_
 #define  rfftwnd_f77_mpi_local_sizes rfftwnd_f77_mpi_local_sizes_
@@ -67,20 +74,32 @@ program grafic1
   real(dp), dimension(:), allocatable :: f
 #endif
   real dx,x1o,x2o,x3o,xoff,fm
-  integer irand,iseed,itide,m1s,m2s,m3s,m1off,m2off,m3off
+  integer irand,itide,m1s,m2s,m3s !,m1off,m2off,m3off
+#ifdef HAVE_LIBGSL
+  integer (c_long) iseed
+#else
+  integer iseed
+#endif
   integer m1t,m2t,m3t,m1offt,m2offt,m3offt
-  integer i1,i2,i3,icomp,idim,nrefine,l1,l2,l3,m1,m2,m3
-  integer ipad, nxs, nys, nzs, iseeds
-  double precision twopi,sigma,lsigma,dsigma,rombin,sigmadispl
+  !integer i1,i2,i3, l1,l2,l3, m1,m2,m3
+  integer icomp,idim,nrefine
+  integer ipad, nxs, nys, nzs
+#ifdef HAVE_LIBGSL
+  integer (c_long) iseeds
+#else
+  integer iseeds
+#endif
+  !double precision lsigma
+  double precision twopi,sigma,dsigma,rombin !,sigmadispl
   double precision dsigmadispl
   parameter (twopi=6.283185307179586d0)
   logical hanning
-  character(len=128) :: filename, in_file, small_file_name, small_kfile_name
+  character(len=128) :: filename, small_file_name, small_kfile_name
   real astart,omegam,omegav,h0,dladt,fomega,vfact,pbar,pcdm
   real omegab,omegahdm,degen_hdm
   real asig,dxr,dpls,dplus,adp
   integer ierr, myid, status
-  integer(i8b) :: plan, iplan
+  type(c_ptr) :: plan, iplan
   integer :: local_z_start,local_nz,local_y_start,local_ny
   integer :: nx, ny, nz
   integer :: total_local_size
@@ -394,10 +413,14 @@ program grafic1
      print*,'  Enter random number seed (9-digit integer, ignored ', &
           &    'if irand=2)'
      read(*,*) iseed
-     print*, iseed
+     write(*,'(i12)') iseed
   endif
   call mpi_barrier(mpi_comm_world,ierr)
+#ifdef HAVE_LIBGSL
+  call mpi_bcast(iseed,1,mpi_long,0,mpi_comm_world,ierr)
+#else
   call mpi_bcast(iseed,1,mpi_integer,0,mpi_comm_world,ierr)
+#endif
   filename=''
   if (myid==0) then
      print*,'  Enter filename of white noise file (or <RETURN> ', &
@@ -443,7 +466,7 @@ program grafic1
 !!$     nys=shtaille%ny
 !!$     nzs=shtaille%nz
      call grafic_read_header_white(small_file_name,nxs,nys,nzs,iseeds)
-     call rfftw3d_f77_mpi_create_plan(plan,mpi_comm_world,nxs,nys,nzs, &
+     call rfftw3d_f77_mpi_create_plan_c_wrap(plan,mpi_comm_world,nxs,nys,nzs, &
           & fftw_real_to_complex,fftw_estimate)
      call rfftwnd_f77_mpi_local_sizes(plan,local_nzs,local_z_starts, &
           & local_nys, local_y_starts, total_local_sizes)
@@ -474,9 +497,9 @@ program grafic1
   ! plans. Beware that domain decomposition is done along nx...
   ! (Slowest varying dimension in the array)
 
-  call rfftw3d_f77_mpi_create_plan(plan,mpi_comm_world,nx,ny,nz, &
+  call rfftw3d_f77_mpi_create_plan_c_wrap(plan,mpi_comm_world,nx,ny,nz, &
        fftw_real_to_complex, fftw_estimate)
-  call rfftw3d_f77_mpi_create_plan(iplan,mpi_comm_world,nx,ny,nz, &
+  call rfftw3d_f77_mpi_create_plan_c_wrap(iplan,mpi_comm_world,nx,ny,nz, &
        fftw_complex_to_real, fftw_estimate)
   call rfftwnd_f77_mpi_local_sizes(plan,local_nz,local_z_start,local_ny, &
        local_y_start,total_local_size)
