@@ -57,6 +57,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   use grafic_io
   use transform
   use normalize
+  use iso_C_binding
 #ifdef HAVE_LIBGSL
   use wrap_gsl_rng_mod
 #endif
@@ -70,14 +71,19 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   !parameter (n12=np1/2,n22=np2/2,n32=np3/2,n23=np2*np3)
   !parameter (n2p1=2*(np1/2+1))
   parameter (npow=30720)
-  integer idim,irand,iseed,itide,m1s,m2s,m3s,m1off,m2off,m3off
+  integer idim,irand,itide,m1s,m2s,m3s,m1off,m2off,m3off
+#ifdef HAVE_LIBGSL
+  integer (c_long) iseed
+#else
+  integer iseed
+#endif
   logical hanning
   character(len=128) :: filename, small_kfile_name
   integer :: ipad
   type(taille) :: headt
   type(cosmo) :: headc
   real astart,pk,dx,xoff,fm
-  integer(i8b) :: plan, iplan
+  type(c_ptr) :: plan, iplan
   integer :: local_nz, local_z_start
   integer :: total_local_size
 #ifdef DOUB
@@ -86,12 +92,17 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   real(sp), dimension(total_local_size) :: f
 #endif
   integer :: myid, nproc, ierr, i_proc
+#ifdef HAVE_LIBGSL
+  integer(c_long) :: seeds(MaxRandNumStreams,1)
+  integer(c_long) :: seed_myid ! avoid repeatedly re-calculating address
+#else
   integer :: seeds(MaxRandNumStreams,IRandNumSize)
-  integer :: seed_myid ! avoid re-calculating address
+#endif
+
   integer(i8b) :: index
   complex(dpc) :: z, ctemp
 
-  real(dp) :: debug
+  !real(dp) :: debug
 
   real lfm
   real(dp) :: twopi,avg,lavg,sigma,lsigma,chisq,lchisq
@@ -101,7 +112,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
   real dk1,dk2,dk3,d3k,akmax,akmaxf,ak,ak23,akk,fact
   real(dp) :: xr
   real ak1,ak2,ak3,ak33,anu,dq,tf,tsav(0:npow),theta
-  logical inflag, white_in
+  !logical inflag, white_in
   external pk
 
   n12=np1/2
@@ -164,25 +175,27 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
      call rans(nproc,iseed,seeds) ! Generate seeds for parallel random number generator
 #endif
      call mpi_barrier(mpi_comm_world,ierr)
-     if(myid.eq.0)print*,'myid,seeds: ',myid,seeds(1:nproc,1)
+     if(myid.eq.0)write(*,'(a,i12,i12)')' myid,seeds: ',myid,seeds(1:nproc,1)
 #ifdef HAVE_LIBGSL
      if(myid.eq.0)then
         ! Send the seeds to each other thread (in GSL case really only
         ! need to send one seed, but seeds is declared for the general case):
         do i_proc=1,nproc-1
            ! TODO: replace by broadcast or scatter?
-           call mpi_send(seeds,MaxRandNumStreams,mpi_integer,i_proc, &
+           call mpi_send(seeds,MaxRandNumStreams,mpi_long,i_proc, &
                 0, &
                 mpi_comm_world, ierr) ! send the seeds
         enddo
      else
-        call mpi_recv(seeds,MaxRandNumStreams,mpi_integer,0, &
+        call mpi_recv(seeds,MaxRandNumStreams,mpi_long,0, &
              0, &
              mpi_comm_world, MPI_STATUS_IGNORE, ierr)
      endif
 #endif
      ! Warning about nproc > MaxRandNumStreams given above.
+#ifdef HAVE_LIBGSL
      seed_myid = seeds(mod(myid,MaxRandNumStreams)+1, 1)
+#endif
      do i3=1,local_nz
         do i2=1,np2
            do i1=1,np1
@@ -201,7 +214,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
         end do
      end do
 #ifdef HAVE_LIBGSL
-     call gauss_gsl(1,xr,1) ! free memory on this thread
+     call gauss_gsl(seed_myid,xr,1) ! free memory on this thread
 #endif
 
 
@@ -223,7 +236,11 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
      call mpi_bcast(i1,1,mpi_integer,0,mpi_comm_world,ierr)
      call mpi_bcast(i2,1,mpi_integer,0,mpi_comm_world,ierr)
      call mpi_bcast(i3,1,mpi_integer,0,mpi_comm_world,ierr)
+#ifdef HAVE_LIBGSL
+     call mpi_bcast(iseed,1,mpi_long,0,mpi_comm_world,ierr)
+#else
      call mpi_bcast(iseed,1,mpi_integer,0,mpi_comm_world,ierr)
+#endif
      if (i1.ne.np1.or.i2.ne.np2.or.i3.ne.np3) then
         if (myid==0) then
            print*,'Error in ic4! file has np1,np2,np3=',i1,i2,i3
@@ -232,7 +249,7 @@ subroutine mpic4(idim,irand,iseed,itide,m1s,m2s,m3s,m1off, &
         call mpi_finalize(ierr)
         stop
      end if
-     if (myid==0) print*,'  Random numbers generated with iseed=',iseed
+     if (myid==0) write(*,'(a,i12)')'   Random numbers generated with iseed=',iseed
      call mpi_barrier(mpi_comm_world,ierr)
      call grafic_read(f,local_nz,local_z_start,np2,np1,filename,white_in=.true.)
 
