@@ -514,8 +514,9 @@ end function pbar
 !cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 subroutine pini
   !  Pini initializes the power spectrum.
-  parameter (pi=3.1415926535898d0)
-  parameter (twopi=2.0d0*pi,fourpi=4.0d0*pi)
+  !parameter (pi=3.1415926535898d0)
+  double precision, parameter :: pi=3.1415926535898d0
+  double precision, parameter :: fourpi=4.0d0*pi !, twopi=2.0d0*pi
   character*128 filename
   parameter (nkmax=1000,nt=11)
   double precision atab(nt)
@@ -820,7 +821,7 @@ subroutine pini
      sig0=fourpi*rombin(dsig8,0.0d0,akmax,1.0d-7)
      pnorm=sigma8**2/sig0
      qrmsps=tcmb*sqrt(pnorm*qq)
-     if (myid==0) write(*,'(a,f15.5)') 'Qrms-ps/micro-K=',qrmsps
+     if (myid==0) write(*,'(a,f15.4)') 'Qrms-ps/micro-K=',qrmsps
   end if
 
   if (myid==0) then
